@@ -30,21 +30,22 @@ TAG = [
     "lymphoproliferative disorder",
     "mastocytosis",
     "metastatic",
-    "monocytosis",
     "myelodysplastic syndrome",
     "myeloproliferative neoplasm",
     "normal",
     "plasma cell neoplasm",
-    "red cell aplasia",
 ]
 
-try:
-    with open("thresh.json") as target:
-        print("Use thresh.json")
-        THRESH = json.load(target)
-except FileNotFoundError:
-    print("Use 0.5 Threshold")
-THRESH = 0.5
+
+def get_thresh():
+    try:
+        with open("thresh.json") as target:
+            print("Use thresh.json")
+            THRESH = json.load(target)
+    except FileNotFoundError:
+        print("Use 0.5 Threshold")
+    THRESH = 0.5
+    return THRESH
 
 
 @dataclass
